@@ -4,6 +4,7 @@
 import numpy as np
 import numpy.linalg as la
 from warnings import warn
+from typing import List, Union
 
 
 class S2T:
@@ -16,7 +17,7 @@ class S2T:
         Parameters
         ----------
         xmin, xmax, dx, ymin, ymax, dy      :   float
-        epsi_bg, mu_bg                      :   float
+        epsi_bg, mu_bg                      :   Union[float, np.ndarray]
         x, y                                :   ndarray
                                                 1d ndarray, If supplied, override xmin etc.
         """
@@ -77,14 +78,14 @@ class S2T:
         self.xx, self.yy = np.meshgrid(self.x, self.y)
 
         # list of box objects
-        self.bxs = []
-        self.bxs_sp = []
-        self.bxs_Lz = []
-        self.bxs_dmLz = []
-        self.bxs_Dr = []
-        self.bxs_dmri = []
-        self.bxs_lg = []
-        self.bxs_dmlg = []
+        self.bxs: List[Bx2] = []
+        self.bxs_sp: List[Bx2] = []
+        self.bxs_Lz: List[Bx2] = []
+        self.bxs_dmLz: List[Bx2] = []
+        self.bxs_Dr: List[Bx2] = []
+        self.bxs_dmri: List[Bx2] = []
+        self.bxs_lg: List[Bx2] = []
+        self.bxs_dmlg: List[Bx2] = []
 
     def a_b(self,
             shp='rct',
@@ -191,8 +192,8 @@ class Bx2:
 
         Parameters
         ----------
-        gmt        :   geometry
-        mtr        :   material
+        gmt        :   Gmt2
+        mtr        :   Mtr
         """
 
         self.gmt = gmt
@@ -206,7 +207,8 @@ class MtrBsc(object):
 
         Parameters
         ----------
-        epsi, mu    :   float or Tuple[float, float, float] or 3x3 ndarray
+        epsi, mu    :   float | (float) | numpy.ndarray
+                        permittivity and permeability. if tuple, it is length of 3. if ndarray, it has shape (3, 3)
         kwargs      :
                         other kwargs not related to materials
         """
@@ -240,6 +242,7 @@ class Mtr(MtrBsc):
         Parameters
         ----------
         knd                             :   str
+                                            Options are:
                                             'sp' (simple),
                                             'Lz' (Lorentz),
                                             'dmLz' (dynamic modulation of delta epsi),
@@ -247,9 +250,14 @@ class Mtr(MtrBsc):
                                             'lg' (loss and gain),
                                             'dmri' (dynamic modulation of real part of index),
                                             'dmlg' (dynamic modulation of loss and gain).
-        epsi_infty_b, mu_infty_b        :   float or Tuple[float, float, float] or 3x3 ndarray
+        epsi_infty_b                    :   float | (float) | numpy.ndarray
+        mu_infty_b                      :   float | (float) | numpy.ndarray
+                                            if tuple it has len 3, if ndarray it has shape (3, 3).
+
                                             The high-frequency permittivity and permeability for use in Lorentz and Drude.
-                                            If not supplied, fall back to epsi_b and mu_b.
+
+                                            If not supplied, fall back to `epsi_b` and `mu_b`.
+
         omgs_rsn                        :   list[float]
                                             resonance frequencies, for use in Lorentz or Drude
         dlts_epsi                       :   list[float]
